@@ -259,7 +259,7 @@ class Real(Dimension):
            orignal space.
         """
         return np.clip(
-            super(Real, self).inverse_transform(Xt).astype(np.float),
+            super(Real, self).inverse_transform(Xt).astype(float),
             self.low, self.high
         )
 
@@ -373,7 +373,7 @@ class Integer(Dimension):
         """
         # The concatenation of all transformed dimensions makes Xt to be
         # of type float, hence the required cast back to int.
-        return super(Integer, self).inverse_transform(Xt).astype(np.int)
+        return super(Integer, self).inverse_transform(Xt).astype(np.int64)
 
     @property
     def bounds(self):
@@ -631,7 +631,7 @@ class Space(object):
            Instantiated Space object
         """
         with open(yml_path, 'rb') as f:
-            config = yaml.load(f)
+            config = yaml.safe_load(f)
 
         dimension_classes = {'real': Real,
                              'integer': Integer,
@@ -860,14 +860,15 @@ class Space(object):
         samples = []
         for i in range(self.n_dims):
             lhs_perm = []
-            # Get evenly distributed samples form one dimension
+            # Get evenly distributed samples from one dimension
             lhs_aranged = self.dimensions[i].lhs_arange(n)
-            perm = np.random.permutation(n)
+            perm = np.random.RandomState(seed=42 + i).permutation(n)
             for p in perm:  # Random permutate the order of the samples
                 lhs_perm.append(lhs_aranged[p])
             samples.append(lhs_perm)
         # Now we have a list of lists with samples for each dimension.
-        # We need to transpose this so thatwe get a list of lists with samples for all the dimensions
+        # We need to transpose this so that we get a list of lists with
+        # samples for all the dimensions
         transposed_samples = []
         for i in range(n):
             row = []
